@@ -1,6 +1,8 @@
 import contextlib
 import io
+import logging
 import time
+import unittest
 from unittest import TestCase
 
 from with_time import LoggingTimer, PrintingTimer
@@ -10,14 +12,23 @@ class TestLoggingTimer(TestCase):
     def test_log_context_manager(self):
         with self.assertLogs(level="INFO") as log:
             with LoggingTimer("sleep"):
-                time.sleep(0.1)
+                time.sleep(0.01)
             self.assertEqual(len(log.records), 1)
             self.assertIn("sleep", log.output[0])
 
+    @unittest.skip("assertNoLogs is in python > 3.10")
+    def test_log_level(self):
+        with self.assertNoLogs(level="INFO"):
+            with LoggingTimer(log_level=logging.DEBUG):
+                time.sleep(0.01)
+        with self.assertLogs(level="DEBUG"):
+            with LoggingTimer(log_level=logging.DEBUG):
+                time.sleep(0.01)
+
     def test_log_decorator(self):
         @LoggingTimer("hello")
         def foo():
-            time.sleep(0.1)
+            time.sleep(0.01)
 
         with self.assertLogs(level="INFO") as log:
             foo()
@@ -26,11 +37,11 @@ class TestLoggingTimer(TestCase):
 
     def test_log_context_manager_process_time(self):
         with self.assertLogs(level="INFO") as log:
-            with LoggingTimer("sleep", timer=time.process_time) as timer:
-                time.sleep(0.1)
+            with LoggingTimer(timer=time.process_time) as timer:
+                time.sleep(0.01)
             self.assertEqual(len(log.records), 1)
-            self.assertIn("sleep", log.output[0])
-            assert timer.elapsed_time < 0.01
+            self.assertIn("Elapsed time", log.output[0])
+            assert timer.elapsed_time <= 0.01
 
 
 class TestPrintingTimer(TestCase):
@@ -38,5 +49,5 @@ class TestPrintingTimer(TestCase):
         stdout = io.StringIO()
         with contextlib.redirect_stdout(stdout):
             with PrintingTimer("sleep"):
-                time.sleep(0.1)
+                time.sleep(0.01)
         assert "sleep" in stdout.getvalue()
